@@ -508,13 +508,13 @@ vcov.reaster <- function(object, standard.deviation = TRUE,
     pW_bee_bee <- pW[is.nonzero.bee, is.nonzero.bee]
     pW_psi_psi <- pW[is.nonzero.psi, is.nonzero.psi]
     pW_psi_bee <- pW[is.nonzero.psi, is.nonzero.bee]
-    pW_bee_bee_inv <- .Call(C_pos_def_mat_inv, pW_bee_bee)
+    pW_bee_bee_inv <- try(.Call(C_pos_def_mat_inv, pW_bee_bee))
     if (inherits(pW_bee_bee_inv, "try-error"))
         stop("Hessian of pW not invertible; no standard errors")
     vcov_psi_psi_inv <- pW_psi_psi -
         pW_psi_bee %*% pW_bee_bee_inv %*% t(pW_psi_bee)
     vcov_psi_psi_inv <- (vcov_psi_psi_inv + t(vcov_psi_psi_inv)) / 2.0
-    vcov_psi_psi <- .Call(C_pos_def_mat_inv, vcov_psi_psi_inv)
+    vcov_psi_psi <- try(.Call(C_pos_def_mat_inv, vcov_psi_psi_inv))
     if (inherits(vcov_psi_psi, "try-error"))
         stop("Hessian of qW not invertible; no standard errors")
 
